"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRuntimeConfig = void 0;
const tslib_1 = require("tslib");
const package_json_1 = tslib_1.__importDefault(require("./package.json"));
const sha256_browser_1 = require("@aws-crypto/sha256-browser");
const fetch_http_handler_1 = require("@aws-sdk/fetch-http-handler");
const invalid_dependency_1 = require("@aws-sdk/invalid-dependency");
const middleware_retry_1 = require("@aws-sdk/middleware-retry");
const util_base64_browser_1 = require("@aws-sdk/util-base64-browser");
const util_body_length_browser_1 = require("@aws-sdk/util-body-length-browser");
const util_user_agent_browser_1 = require("@aws-sdk/util-user-agent-browser");
const util_utf8_browser_1 = require("@aws-sdk/util-utf8-browser");
const runtimeConfig_shared_1 = require("./runtimeConfig.shared");
/**
 * @internal
 */
const getRuntimeConfig = (config = {}) => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p;
    const clientSharedValues = runtimeConfig_shared_1.getRuntimeConfig(config);
    return {
        ...clientSharedValues,
        ...config,
        runtime: "browser",
        base64Decoder: (_a = config.base64Decoder) !== null && _a !== void 0 ? _a : util_base64_browser_1.fromBase64,
        base64Encoder: (_b = config.base64Encoder) !== null && _b !== void 0 ? _b : util_base64_browser_1.toBase64,
        bodyLengthChecker: (_c = config.bodyLengthChecker) !== null && _c !== void 0 ? _c : util_body_length_browser_1.calculateBodyLength,
        credentialDefaultProvider: (_d = config.credentialDefaultProvider) !== null && _d !== void 0 ? _d : ((_) => () => Promise.reject(new Error("Credential is missing"))),
        defaultUserAgentProvider: (_e = config.defaultUserAgentProvider) !== null && _e !== void 0 ? _e : util_user_agent_browser_1.defaultUserAgent({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        endpointDiscoveryEnabledProvider: (_f = config.endpointDiscoveryEnabledProvider) !== null && _f !== void 0 ? _f : (() => Promise.resolve(undefined)),
        maxAttempts: (_g = config.maxAttempts) !== null && _g !== void 0 ? _g : middleware_retry_1.DEFAULT_MAX_ATTEMPTS,
        region: (_h = config.region) !== null && _h !== void 0 ? _h : invalid_dependency_1.invalidProvider("Region is missing"),
        requestHandler: (_j = config.requestHandler) !== null && _j !== void 0 ? _j : new fetch_http_handler_1.FetchHttpHandler(),
        retryModeProvider: (_k = config.retryModeProvider) !== null && _k !== void 0 ? _k : (() => Promise.resolve(middleware_retry_1.DEFAULT_RETRY_MODE)),
        sha256: (_l = config.sha256) !== null && _l !== void 0 ? _l : sha256_browser_1.Sha256,
        streamCollector: (_m = config.streamCollector) !== null && _m !== void 0 ? _m : fetch_http_handler_1.streamCollector,
        utf8Decoder: (_o = config.utf8Decoder) !== null && _o !== void 0 ? _o : util_utf8_browser_1.fromUtf8,
        utf8Encoder: (_p = config.utf8Encoder) !== null && _p !== void 0 ? _p : util_utf8_browser_1.toUtf8,
    };
};
exports.getRuntimeConfig = getRuntimeConfig;
//# sourceMappingURL=runtimeConfig.browser.js.map